@@ -1,30 +1,31 @@
-
-# This file was created by mkconfig.rb when ruby was built.  Any
-# changes made to this file will be lost the next time ruby is built.
+# frozen-string-literal: false
+# This file was created by mkconfig.rb when ruby was built.  It contains
+# build information for ruby which is used e.g. by mkmf to build
+# compatible native extensions.  Any changes made to this file will be
+# lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.2.10"[/^[0-9]+[.][0-9]+[.]/]) or
-    raise "ruby lib version (2.2.10) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.3.") or
+    raise "ruby lib version (2.3.8) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.2/2.2.0/x86_64-darwin17")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.3/2.3.0/x86_64-darwin17")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "2"
+  CONFIG["MINOR"] = "3"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "489"
+  CONFIG["PATCHLEVEL"] = "459"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.2"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.2"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.3"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.3"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(MAJOR).$(MINOR).$(TEENY)"
-  CONFIG["DESTDIR"] = ""
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.2.pc"
+  CONFIG["ruby_pc"] = "ruby-2.3.pc"
   CONFIG["PACKAGE"] = "ruby"
-  CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
+  CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["NROFF"] = "/usr/bin/nroff"
@@ -37,7 +38,8 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--without-gmp' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.2' '--with-rubylibprefix=/opt/local/lib/ruby2.2' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl10/lib/pkgconfig'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--without-gmp' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.3' '--with-rubylibprefix=/opt/local/lib/ruby2.3' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl10/lib/pkgconfig'"
+  CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
@@ -46,7 +48,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.2.0"
+  CONFIG["ruby_version"] = "2.3.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin17"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -74,7 +76,7 @@ module RbConfig
   CONFIG["DLDLIBS"] = ""
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static -framework CoreFoundation"
+  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static -framework Foundation"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_BASE_NAME).$(MAJOR).$(MINOR).dylib lib$(RUBY_INSTALL_NAME).dylib"
@@ -88,32 +90,22 @@ module RbConfig
   CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
-  CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
-  CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
-  CONFIG["cppflags"] = ""
   CONFIG["NULLCMD"] = ":"
   CONFIG["DLNOBJ"] = "dln.o"
-  CONFIG["INSTALLDOC"] = "nodoc"
-  CONFIG["CAPITARGET"] = "nodoc"
-  CONFIG["RDOCTARGET"] = "nodoc"
-  CONFIG["DTRACE_REBUILD"] = ""
-  CONFIG["DTRACE_OBJ"] = ""
-  CONFIG["DTRACE_EXT"] = "d"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
   CONFIG["EXTOUT"] = ".ext"
-  CONFIG["RUNRUBY_COMMAND"] = "$(MINIRUBY) $(srcdir)/tool/runruby.rb --extout=$(EXTOUT) $(RUNRUBYOPT)"
-  CONFIG["PREP"] = "miniruby$(EXEEXT)"
-  CONFIG["BTESTRUBY"] = "$(MINIRUBY)"
+  CONFIG["PREP"] = "miniruby$(EXEEXT) ruby-runner$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.2"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.3"
   CONFIG["setup"] = "Setup"
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -A -n"
   CONFIG["TRY_LINK"] = ""
+  CONFIG["PRELOADENV"] = "DYLD_INSERT_LIBRARIES"
   CONFIG["LIBPATHENV"] = "DYLD_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
@@ -127,7 +119,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fno-common"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = " -arch x86_64"
-  CONFIG["DLDFLAGS"] = "-Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib "
+  CONFIG["DLDFLAGS"] = "-Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib"
   CONFIG["ALLOCA"] = ""
   CONFIG["codesign"] = "codesign"
   CONFIG["POSTLINK"] = "test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@"
@@ -143,7 +135,6 @@ module RbConfig
   CONFIG["PYTHON"] = ""
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
-  CONFIG["DTRACE"] = "dtrace"
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
@@ -158,8 +149,9 @@ module RbConfig
   CONFIG["OBJDUMP"] = "objdump"
   CONFIG["ASFLAGS"] = ""
   CONFIG["AS"] = "as"
-  CONFIG["AR"] = "ar"
-  CONFIG["RANLIB"] = "ranlib"
+  CONFIG["ARFLAGS"] = "-no_warning_for_no_symbols -o "
+  CONFIG["AR"] = "libtool -static"
+  CONFIG["RANLIB"] = ":"
   CONFIG["try_header"] = ""
   CONFIG["CC_VERSION"] = "$(CC) -v"
   CONFIG["COUTFLAG"] = "-o "
@@ -174,8 +166,8 @@ module RbConfig
   CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl10/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -Wl,-headerpad_max_install_names -fstack-protector -L/opt/local/lib -L/opt/local/lib "
-  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -fno-common"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector -L/opt/local/lib"
+  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -fno-common"
   CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["CC"] = "/usr/bin/clang"
   CONFIG["NACL_LIB_PATH"] = ""
@@ -186,19 +178,21 @@ module RbConfig
   CONFIG["target_vendor"] = "apple"
   CONFIG["target_cpu"] = "x86_64"
   CONFIG["target"] = "x86_64-apple-darwin17"
-  CONFIG["host_os"] = "darwin17"
+  CONFIG["host_os"] = "darwin17.7.0"
   CONFIG["host_vendor"] = "apple"
   CONFIG["host_cpu"] = "x86_64"
-  CONFIG["host"] = "x86_64-apple-darwin17"
+  CONFIG["host"] = "x86_64-apple-darwin17.7.0"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "darwin17"
+  CONFIG["build_os"] = "darwin17.7.0"
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "x86_64"
-  CONFIG["build"] = "x86_64-apple-darwin17"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.10"
-  CONFIG["HAVE_BASERUBY"] = "yes"
+  CONFIG["build"] = "x86_64-apple-darwin17.7.0"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.8"
+  CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cppflags"] = ""
+  CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -216,7 +210,7 @@ module RbConfig
   CONFIG["htmldir"] = "$(docdir)"
   CONFIG["infodir"] = "$(datarootdir)/info"
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
-  CONFIG["oldincludedir"] = "/usr/include"
+  CONFIG["oldincludedir"] = "$(SDKROOT)""/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
   CONFIG["localstatedir"] = "$(prefix)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
@@ -226,7 +220,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.2&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&2.3&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -236,6 +230,7 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
+  CONFIG["SDKROOT"] = ENV["SDKROOT"] || "" # don't run xcrun everytime, usually useless.
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   MAKEFILE_CONFIG = {}
